@@ -1,23 +1,35 @@
+"""
+Main CLI entrypoint.
+"""
 import sys
 
 
 def print_info() -> None:
+    """
+    Print package info to stdout.
+    """
     print(
-        "Type annotations for boto3.WAFV2 1.17.61\n"
-        "Version:         1.17.61.1\n"
-        "Builder version: 4.8.1\n"
+        "Type annotations for boto3.WAFV2 1.18.34\n"
+        "Version:         1.18.34\n"
+        "Builder version: 5.2.0\n"
         "Docs:            https://pypi.org/project/mypy-boto3-wafv2/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/wafv2.html#WAFV2\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/wafv2.html#WAFV2\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.61.1")
+    """
+    Print package version to stdout.
+    """
+    print("1.18.34")
 
 
 def main() -> None:
+    """
+    Main CLI entrypoint.
+    """
     if "--version" in sys.argv:
         return print_version()
     print_info()
